summaryrefslogtreecommitdiffstats
path: root/chalk/ui/kis_custom_image_widget.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/ui/kis_custom_image_widget.h')
-rw-r--r--chalk/ui/kis_custom_image_widget.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chalk/ui/kis_custom_image_widget.h b/chalk/ui/kis_custom_image_widget.h
index eef443dc..a36d44bc 100644
--- a/chalk/ui/kis_custom_image_widget.h
+++ b/chalk/ui/kis_custom_image_widget.h
@@ -36,10 +36,10 @@ class KisCustomImageWidget : public WdgNewImage {
public:
/**
* Constructor. Please note that this class is being used/created by KisDoc.
* @param tqparent the tqparent widget
* @param doc the document that wants to be altered
*/
- KisCustomImageWidget(TQWidget *tqparent, KisDoc *doc, TQ_INT32 defWidth, TQ_INT32 defHeight, double resolution, TQString defColorSpaceName, TQString imageName);
+ KisCustomImageWidget(TQWidget *parent, KisDoc *doc, TQ_INT32 defWidth, TQ_INT32 defHeight, double resolution, TQString defColorSpaceName, TQString imageName);
private slots:
void buttonClicked();
@@ -36,10 +36,10 @@ class KisCustomImageWidget : public WdgNewImage {
/**
* Constructor. Please note that this class is being used/created by KisDoc.
- * @param tqparent the tqparent widget
+ * @param parent the parent widget
* @param doc the document that wants to be altered
*/